@@ -3,15 +3,15 @@ package File::HomeDir::Darwin;
 # Basic implementation for the Dawin family of operating systems.
 # This includes (most prominently) Mac OS X.
 
-use 5.005;
+use 5.00503;
 use strict;
+use Cwd                 ();
+use Carp                ();
 use File::HomeDir::Unix ();
-use Carp ();
-use Cwd ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.71_03';
+	$VERSION = '0.83_01';
 	@ISA     = 'File::HomeDir::Unix';
 }
 
@@ -112,7 +112,7 @@ sub _find_folder {
 sub users_home {
 	my $class = shift;
 	my $home  = $class->SUPER::users_home(@_);
-	return Cwd::abs_path($home);
+	return defined $home ? Cwd::abs_path($home) : undef;
 }
 
 # in theory this can be done, but for now, let's cheat, since the
@@ -141,7 +141,8 @@ sub _to_user {
 	my ($class, $path, $name) = @_;
 	my $my_home    = $class->my_home;
 	my $users_home = $class->users_home($name);
-	$path =~ s/^Q$my_home/$users_home/;
+	defined $users_home or return undef;
+	$path =~ s/^\Q$my_home/$users_home/;
 	return $path;
 }
 
